@@ -1,6 +1,27 @@
+#
+#   xts: eXtensible time-series 
+#
+#   Copyright (C) 2008  Jeffrey A. Ryan jeff.a.ryan @ gmail.com
+#
+#   Contributions from Joshua M. Ulrich
+#
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 3 of the License, or
+#   (at your option) any later version.
+#
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License
+#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
 # optimized periodic apply functions
 #
-`timeBased` <-
+`is.timeBased` <- `timeBased` <-
 function(x) {
 if (!any(sapply(c("Date", "POSIXct", "chron", "dates", "times", 
         "timeDate", "yearmon", "yearqtr"), function(xx) inherits(x, 
@@ -9,6 +30,11 @@ if (!any(sapply(c("Date", "POSIXct", "chron", "dates", "times",
     } else TRUE
 }
 
+make.timeBased <- function(x, class='POSIXct', ...)
+{
+  do.call(class, list(x,...))
+}
+
 `period.sum` <-
 function(x,INDEX) {
   if(NCOL(x) > 1) stop("single column data only")
