@@ -27,7 +27,6 @@ function(x,...) {
 
   # strip all non-'core' attributes so they're not attached to the Data slot
   x.attr <- attributes(x)
-  x.index <- index(x)
   xx <- structure(x,dimnames=x.attr$dimnames,index=x.attr$index)
   original.attr <- attributes(x)[!names(attributes(x)) %in% 
                                  c("dim","dimnames","index","class")]
@@ -35,7 +34,7 @@ function(x,...) {
     attr(xx,i) <- NULL
   }
 
-  timeSeries(coredata(xx),charvec=as.character(x.index),format=x.attr$format,
+  timeSeries(coredata(xx),charvec=index(x),format=x.attr$format,
              zone=x.attr$FinCenter,FinCenter=x.attr$FinCenter,
              recordIDs=x.attr$recordIDs,title=x.attr$title,
              documentation=x.attr$documentation,...)
